Name:          openstack-savanna
Version:       2014.1.b2
Release:       3%{?dist}
Summary:       Apache Hadoop cluster management on OpenStack
License:       ASL 2.0
URL:           https://launchpad.net/savanna
Source0:       http://tarballs.openstack.org/savanna/savanna-%{version}.tar.gz
Source1:       openstack-savanna-api.service
BuildArch:     noarch

BuildRequires: python2-devel
BuildRequires: python-setuptools
BuildRequires: python-oslo-sphinx
BuildRequires: python-sphinxcontrib-httpdomain
BuildRequires: python-pbr >= 0.5.19
# Need systemd-units for _unitdir macro
BuildRequires: systemd-units
# Needed by check
#BuildRequires: python-unittest2
#BuildRequires: python-mock

Requires: python-alembic
#?Babel>=1.3?
Requires: python-eventlet
Requires: python-flask
Requires: python-iso8601
Requires: python-jsonschema >= 1.3.0
#?kombu>=2.4.8?
Requires: python-oslo-config >= 1.2.0
# >=1.8.0 needed for new namespace code (connect w/ sock param)
Requires: python-paramiko >= 1.8.0
Requires: python-pbr
Requires: python-cinderclient >= 1.0.5
Requires: python-keystoneclient >= 0.3.2
Requires: python-novaclient >= 2.15.0
Requires: python-swiftclient
Requires: python-neutronclient
Requires: python-six >= 1.4.1
Requires: python-stevedore >= 0.13
Requires: python-sqlalchemy
#?WebOb>=1.2.3?

Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
Requires(pre):    shadow-utils


%description
Savanna provides the ability to elastically manage Apache Hadoop
clusters on OpenStack.


%prep
%setup -q -n savanna-%{version}
rm -rf savanna.egg-info
rm -f {test-,}requirements.txt
sed -i 's/0.5.21/0.5.19/' setup.py
# The data_files glob appears broken in pbr 0.5.19, so be explicit
sed -i 's,etc/savanna/\*,etc/savanna/savanna.conf.sample etc/savanna/savanna.conf.sample-full,' setup.cfg


%build
%{__python} setup.py build

export PYTHONPATH=$PWD:${PYTHONPATH}
# Note: json warnings likely resolved w/ pygments 1.5 (not yet in Fedora)
sphinx-build doc/source html
rm -rf html/.{doctrees,buildinfo}


%install
%{__python} setup.py install --skip-build --root %{buildroot}

install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/openstack-savanna-api.service

HOME=%{_sharedstatedir}/savanna
install -d -m 700 %{buildroot}$HOME

# TODO: os_admin_username/password/tenant_name
SAMPLE=%{buildroot}%{_datadir}/savanna/savanna.conf.sample
CONF=%{buildroot}%{_sysconfdir}/savanna/savanna.conf
install -d -m 755 $(dirname $CONF)
install -D -m 640 $SAMPLE $CONF
sed -i -e "s,.*connection=.*,connection=sqlite:///$HOME/savanna-server.db," $CONF

# Do not package tests
rm -rf %{buildroot}%{python_sitelib}/savanna/tests

mkdir -p -m0755 %{buildroot}/%{_var}/log/savanna


#%%check
#%%{__python} setup.py test


%pre
# Origin: http://fedoraproject.org/wiki/Packaging:UsersAndGroups#Dynamic_allocation
USERNAME=savanna
GROUPNAME=$USERNAME
HOMEDIR=%{_sharedstatedir}/savanna
getent group $GROUPNAME >/dev/null || groupadd -r $GROUPNAME
getent passwd $USERNAME >/dev/null || \
  useradd -r -g $GROUPNAME -G $GROUPNAME -d $HOMEDIR -s /sbin/nologin \
  -c "Savanna Daemons" $USERNAME
exit 0


%post
# TODO: if db file then savanna-db-manage update head
# TODO: savanna-db-manage should read /etc/savanna/savanna.conf by default
#       https://bugs.launchpad.net/savanna/+bug/1202227
%systemd_post openstack-savanna-api.service


%preun
%systemd_preun openstack-savanna-api.service


%postun
%systemd_postun_with_restart openstack-savanna-api.service


%files
%doc html README.rst LICENSE
%dir %{_sysconfdir}/savanna
# Note: this file is not readable because it holds auth credentials
%config(noreplace) %attr(-, root, savanna) %{_sysconfdir}/savanna/savanna.conf
%{_bindir}/savanna-api
%{_bindir}/_savanna-subprocess
%{_bindir}/savanna-db-manage
%{_unitdir}/openstack-savanna-api.service
%dir %attr(-, savanna, savanna) %{_sharedstatedir}/savanna
# Note: permissions on savanna's home are intentially 0700
%dir %{_datadir}/savanna
%{_datadir}/savanna/savanna.conf.sample
%{_datadir}/savanna/savanna.conf.sample-full
%{python_sitelib}/savanna
%{python_sitelib}/savanna-%{version}-py?.?.egg-info
%defattr(-,savanna,savanna,-)
%dir %{_var}/log/savanna



%changelog
* Mon Jan 27 2014 Matthew Farrellee <matt@redhat> - 2014.1.b2-3
- Require stevedore >= 0.13

* Mon Jan 27 2014 Matthew Farrellee <matt@redhat> - 2014.1.b2-2
- Added space around paramiko requires

* Mon Jan 27 2014 Matthew Farrellee <matt@redhat> - 2014.1.b2-1
- 2014.1.b2 release

* Sat Jan 18 2014 Matthew Farrellee <matt@redhat> - 2014.1.b1-1
- 2014.1.b1 release

* Tue Oct 22 2013 Matthew Farrellee <matt@redhat> - 0.3-3
- Include Vanilla Plugin SQL files (for EDP)

* Tue Oct 22 2013 Matthew Farrellee <matt@redhat> - 0.3-2
- Fix db connection url

* Sun Oct 20 2013 Matthew Farrellee <matt@redhat> - 0.3-1
- 0.3 release
- Enable logging into /var/log/savanna

* Fri Oct 11 2013 Matthew Farrellee <matt@redhat> - 0.3-0.2
- 0.3 rc3 build

* Mon Aug 12 2013 Matthew Farrellee <matt@redhat> - 0.2-3
- Updates to build on F19,
-  Require systemd-units, allows mockbuild to work
-  Remove setuptools-git from setup.py, no downloads during build

* Fri Aug 09 2013 Matthew Farrellee <matt@redhat> - 0.2-2
- Updates from package review BZ986615

* Mon Jul 15 2013 Matthew Farrellee <matt@redhat> - 0.2-1
- Initial package
